##  Implementation Details
SAP LeanIX queries Netskope through/api/v2/events/data/application endpoint to discover SaaS applications. This API allows organizations to monitor and analyze user activity within cloud applications based on traffic and logs. The API filters out events that lack an associated application value, ensuring the data's relevance and integrity. Application events are specifically triggered by user actions within SaaS applications, providing insights into user interactions.
The integration initially pulls application event data from Netskope for the past 15 days and thereafter on a daily basis. You can cross-check discovered services in the Netskope Admin Console by reviewing the App Usage Summary under Reports. However, it is difficult to cross-check the exact report as the time range in Netskope varies.
To efficiently use the API and avoid disruptions, SAP LeanIX adheres to the rate limits detailed in the API documentation. For more information, see [Netskope API V2 Data Export Rate Limits![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdocs.netskope.com%2Fen%2Fusing-the-rest-api-v2-dataexport-iterator-endpoints%2F%23idm44857851742432 "https://docs.netskope.com/en/using-the-rest-api-v2-dataexport-iterator-endpoints/#idm44857851742432"). For more detailed rate limit information, including global limits, you can access the settings section of the Netskope API portal.
Integration Categories | Authentication Mechanism | API Endpoints Used | Netskope resource
---|---|---|---
Cloud Access Security Brokers (CASB) | REST API - [OAuth![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdocs.netskope.com%2Fen%2Fnetskope-help%2Fadmin-console%2Frest-api%2Frest-api-v2-overview-312207%2F "https://docs.netskope.com/en/netskope-help/admin-console/rest-api/rest-api-v2-overview-312207/") |  For API authentication: N/A For SaaS discovery: /api/v2/events/data/application |  [Events![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdocs.netskope.com%2Fen%2Frest-api-v2-overview-312207.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://docs.netskope.com/en/rest-api-v2-overview-312207.html")


